Module blaxel.core.sandbox.client.models.process_request
========================================================

Classes
-------

`ProcessRequest(command: str, env: blaxel.core.sandbox.client.types.Unset | ForwardRef('ProcessRequestEnv') = <blaxel.core.sandbox.client.types.Unset object>, name: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, timeout: blaxel.core.sandbox.client.types.Unset | int = <blaxel.core.sandbox.client.types.Unset object>, wait_for_completion: blaxel.core.sandbox.client.types.Unset | bool = <blaxel.core.sandbox.client.types.Unset object>, wait_for_ports: blaxel.core.sandbox.client.types.Unset | list[int] = <blaxel.core.sandbox.client.types.Unset object>, working_dir: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>)`
:   Attributes:
        command (str):  Example: ls -la.
        env (Union[Unset, ProcessRequestEnv]):  Example: {'{"PORT"': ' "3000"}'}.
        name (Union[Unset, str]):  Example: my-process.
        timeout (Union[Unset, int]):  Example: 30.
        wait_for_completion (Union[Unset, bool]):
        wait_for_ports (Union[Unset, list[int]]):  Example: [3000, 8080].
        working_dir (Union[Unset, str]):  Example: /home/user.
    
    Method generated by attrs for class ProcessRequest.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `command`
    :

    `env`
    :

    `name`
    :

    `timeout`
    :

    `wait_for_completion`
    :

    `wait_for_ports`
    :

    `working_dir`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :